==> ejc-sddjsorg-impl-3.0.0-20211020.020248-35-sources.jar: com/ejianc/business/production/bean/ResidualPropertyEntity.java <==
package com.ejianc.business.production.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 产权登记-剩余财产分配情况
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sddjsorg_production_residual_property")
public class ResidualPropertyEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="captail_name")
    private java.lang.String captailName; // 出资人名称
    @TableField(value="residual_property")
    private java.math.BigDecimal residualProperty; // 剩余财产分配结果
    @TableField(value="residual_property_big")
    private java.lang.String residualPropertyBig; // 剩余财产分配结果(大写)
    
    
    

    /**
     * 出资人名称
     */
    public java.lang.String getCaptailName() {
        return captailName;
    }

    /**
     * 出资人名称
     */
    public void setCaptailName(java.lang.String captailName) {
        this.captailName = captailName;
    }
    /**
     * 剩余财产分配结果
     */
    public java.math.BigDecimal getResidualProperty() {
        return residualProperty;
    }

    /**
     * 剩余财产分配结果
     */
    public void setResidualProperty(java.math.BigDecimal residualProperty) {
        this.residualProperty = residualProperty;
    }
    /**
     * 剩余财产分配结果(大写)
     */
    public java.lang.String getResidualPropertyBig() {
        return residualPropertyBig;
    }

    /**
     * 剩余财产分配结果(大写)
     */
    public void setResidualPropertyBig(java.lang.String residualPropertyBig) {
        this.residualPropertyBig = residualPropertyBig;
    }
    
}

==> ejc-sddjsorg-impl-3.0.0-20211210.104338-148-sources.jar: com/ejianc/business/production/bean/ResidualPropertyEntity.java <==
package com.ejianc.business.production.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 产权登记-剩余财产分配情况
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sddjsorg_production_residual_property")
public class ResidualPropertyEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="captail_name")
    private java.lang.String captailName; // 出资人名称
    @TableField(value="residual_property")
    private java.math.BigDecimal residualProperty; // 剩余财产分配结果
    @TableField(value="residual_property_big")
    private java.lang.String residualPropertyBig; // 剩余财产分配结果(大写)
    @TableField(value="pid")
    private Long pid;
    
    

    /**
     * 出资人名称
     */
    public java.lang.String getCaptailName() {
        return captailName;
    }

    /**
     * 出资人名称
     */
    public void setCaptailName(java.lang.String captailName) {
        this.captailName = captailName;
    }
    /**
     * 剩余财产分配结果
     */
    public java.math.BigDecimal getResidualProperty() {
        return residualProperty;
    }

    /**
     * 剩余财产分配结果
     */
    public void setResidualProperty(java.math.BigDecimal residualProperty) {
        this.residualProperty = residualProperty;
    }
    /**
     * 剩余财产分配结果(大写)
     */
    public java.lang.String getResidualPropertyBig() {
        return residualPropertyBig;
    }

    /**
     * 剩余财产分配结果(大写)
     */
    public void setResidualPropertyBig(java.lang.String residualPropertyBig) {
        this.residualPropertyBig = residualPropertyBig;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
}
